Constraint
----------


Use Constraint to constrain your models parameters.


.. autosummary::
    :toctree: _generated/constraint

    zfit.constraint.GaussianConstraint
    zfit.constraint.PoissonConstraint
    zfit.constraint.LogNormalConstraint
    zfit.constraint.SimpleConstraint
